excel-vue-i18n

The CLI application to genetare Vue i18n local file from excel
3,824 9
Install
npm install excel-vue-i18n
Latest Version:1.1.0
License:ISC
Last Updated:Sep 19, 2020
Links: GitHub  ·  npm
Maintainer: grafikri

preview

Excel Vue i18n

You can create Vue i18n locale files from Excel via this CLI application

Installation

$ npm i -g excel-vue-i18n

Examples

This line will generate json locale files depend on their key values that exist in the excel file. The JSON file will be generated under the root /locale as default.

$ excelVueI18n -p myLangFile.xlsx

If you want to specify path

$ excelVueI18n -p file/myLangFile.xlsx

If you want to generate one single file that contains all locales information you can use -s option.

$ excelVueI18n -p file/myLangFile.xlsx -s true

If you use -o option with -s you can also specify genetared file name like this

$ excelVueI18n -p file/myLangFile.xlsx -s true -o myLocaleFile

then your genetared file name will be named as myLocaleFile.json under the root of /locale

Note: When -s option didn't use -o option will be ignored because file names will be their lang codes

Specifying the folder path for the generated file(s) you can use -f option.

$ excelVueI18n -p myLangFile.xlsx -f langFolder

then your genetared file name will be named as myLocaleFile.json under the root of /langFolder

Reference

Usage: -p <name>
Usage: -f <name>
Usage: -s <name>
Usage: -o <name>

Options:
  --help                Show help                                      [boolean]
  --version             Show version number                            [boolean]
  -p, --path            Source excel file path               [string] [required]
  -f, --folder          The folder that the files will be created into it
                                                                        [string]
  -s, --singleFile      When entered as true just one locale file will be
                        created                                        [boolean]
  -o, --outputFileName  Output file name that will be named when single param
                        sent as true                                    [string]

Related Packages

@vintl/vintl

Integrate @formatjs/intl into your Vue apps for easier internationalisation

10,663 5
@makemepulse/tool-i18n

Handle locales with Google Spreadsheet and vue-i18n plugin

5,419 0
vite-plugin-vue-viai18n

i18n transform plugin for vite/vue which can generate message key automatically

2,940 0
vue-i18n-loader

Another i18n solution for Vue (Nuxt) with auto generated keys

2,477 0

Version History

Version Released License
1.1.0 ISC
1.0.1 ISC
1.0.0 ISC
0.0.8 ISC
0.0.7 ISC